a character giving the names of the optimization problems
to be returned, if x is "all" all available problems
are returned, if x is the name of a single problem the
given problem is returned. If x is missing a listing
of all available problems is returned. If x is "metainfo"
the meta information about the problems is returned.
folder
the folder where the optimization problems are stored.
Details
The function miplib searches in the given folder for
.rds files and returns them.
# NOT RUN {## list all available MIPLIB-2010 problemsmiplib()
## get all miplib problemsmiplib("all")
## get a single problemmiplib("rmine6")
## get the meta informationmiplib("metainfo")
# }